@@ -8,7 +8,6 @@
 #define DUNE_ISTL_WITH_CHECKING
 #endif
 #include <dune/common/fmatrix.hh>
-#include <dune/common/fassign.hh>
 #include <dune/common/classname.hh>
 #include <iostream>
 #include <algorithm>
@@ -162,9 +161,10 @@ void test_mult(FieldMatrix<K, n, m>& A,
   A.mmv(v,f);
   A.mmtv(f,v);
   A.mmhv(f,v);
-  A.usmv(0.5,v,f);
-  A.usmtv(0.5,f,v);
-  A.usmhv(0.5,f,v);
+  K scalar = (K)(0.5);
+  A.usmv(scalar,v,f);
+  A.usmtv(scalar,f,v);
+  A.usmhv(scalar,f,v);
 }
 
 
@@ -327,7 +327,7 @@ void test_matrix()
 
     FieldMatrix<K,n,n+1> AB3 = Bref.leftmultiplyany(A);
     AB3 -= AB;
-    if (std::abs(AB3.infinity_norm() > 1e-10))
+    if (std::abs(AB3.infinity_norm()) > 1e-10)
       DUNE_THROW(FMatrixError,"Leftmultiplyany test failed!");
 
     FieldMatrix<K,n,n+1> CA = Aref.leftmultiplyany(C);
@@ -452,16 +452,16 @@ void test_ev()
    * A small, nonzero eigenvalue
 
    */
-  Dune::FieldMatrix<ft,8,8> A;
-  A <<=
-    611, 196, -192, 407, -8, -52, -49, 29, Dune::nextRow,
-  196, 899, 113, -192, -71, -43, -8, -44, Dune::nextRow,
-  -192, 113, 899, 196, 61, 49, 8, 52, Dune::nextRow,
-  407, -192, 196, 611, 8, 44, 59, -23, Dune::nextRow,
-  -8, -71, 61, 8, 411, -599, 208, 208, Dune::nextRow,
-  -52, -43, 49, 44, -599, 411, 208, 208, Dune::nextRow,
-  -49, -8, 8, 59, 208, 208, 99, -911, Dune::nextRow,
-  29, -44, 52, -23, 208, 208, -911, 99;
+  Dune::FieldMatrix<ft,8,8> A = {
+    { 611, 196, -192, 407, -8, -52, -49, 29 },
+    { 196, 899, 113, -192, -71, -43, -8, -44 },
+    { -192, 113, 899, 196, 61, 49, 8, 52 },
+    { 407, -192, 196, 611, 8, 44, 59, -23 },
+    { -8, -71, 61, 8, 411, -599, 208, 208 },
+    { -52, -43, 49, 44, -599, 411, 208, 208 },
+    { -49, -8, 8, 59, 208, 208, 99, -911 },
+    { 29, -44, 52, -23, 208, 208, -911, 99}
+  };
 
   // compute eigenvalues
   Dune::FieldVector<ft,8> eig;
@@ -476,15 +476,14 @@ void test_ev()
      > eig(rosser())
 
    */
-  ref <<=
-    -1.02004901843000e+03,
+  ref = { -1.02004901843000e+03,
   -4.14362871168386e-14,
   9.80486407214362e-02,
   1.00000000000000e+03,
   1.00000000000000e+03,
   1.01990195135928e+03,
   1.02000000000000e+03,
-  1.02004901843000e+03;
+  1.02004901843000e+03 };
 
   if( (ref - eig).two_norm() > 1e-10 )
   {
@@ -553,11 +552,25 @@ void test_interface()
   checkMatrixInterface< FMatrix, Traits >( m );
 }
 
+void test_initialisation()
+{
+  DUNE_UNUSED Dune::FieldMatrix<int, 2, 2> const A = {
+    { 1, 2 },
+    { 3, 4 }
+  };
+
+  assert(A[0][0] == 1);
+  assert(A[0][1] == 2);
+  assert(A[1][0] == 3);
+  assert(A[1][1] == 4);
+}
+
 int main()
 {
   try {
     test_nan();
     test_infinity_norms();
+    test_initialisation();
 
     // test 1 x 1 matrices
     test_interface<float, 1, 1>();
