@@ -6,8 +6,8 @@
 #include <dune/common/fvector.hh>
 #include <dune/common/exceptions.hh>
 #include <dune/common/typetraits.hh>
-#include <dune/common/static_assert.hh>
 #include <dune/common/classname.hh>
+#include <dune/common/gmpfield.hh>
 #include <iostream>
 #include <complex>
 #include <typeinfo>
@@ -33,17 +33,23 @@ struct FieldVectorMainTest
 
     std::cout << __func__ << "\t ( " << className(v) << " )" << std::endl;
 
+    // test exported types
+    static_assert(
+      Dune::is_same<ft,typename FieldVector<ft,d>::value_type>::value,
+      "FieldVector::value_type is not the correct type"
+    );
+
     // test traits
-    dune_static_assert(
+    static_assert(
       ( Dune::is_same< typename Dune::FieldTraits<
                 FieldVector<ft,d> >::field_type, ft >::value ),
       "FieldTraits<FieldVector> yields wrong field_type"
       );
-    dune_static_assert(
+    static_assert(
       ( Dune::is_same< typename Dune::FieldTraits<ft>::real_type, rt >::value ),
       "FieldTraits<field_type> yields wrong real_type"
       );
-    dune_static_assert(
+    static_assert(
       ( Dune::is_same< typename Dune::FieldTraits<
                 FieldVector<ft,d> >::real_type, rt >::value ),
       "FieldTraits<FieldVector> yields wrong real_type"
@@ -101,13 +107,14 @@ struct FieldVectorMainTest
 };
 
 
-template<class ft>
+template<class ft, class testft=ft>
 struct ScalarOperatorTest
 {
   ScalarOperatorTest()
   {
-    ft a = 1;
-    ft c = 2;
+    // testft has to initializable with an int
+    testft a = 1;
+    testft c = 2;
     FieldVector<ft,1> v(2);
     FieldVector<ft,1> w(2);
     bool b DUNE_UNUSED;
@@ -126,25 +133,25 @@ struct ScalarOperatorTest
     a = v + a;
     a = v - a;
     a = v * a;
-    a += (ft)1; // make sure a!=0
+    a += 1; // make sure a!=0
     a = v / a;
 
     v = v + a;
     v = v - a;
     v = v * a;
-    a += (ft)1; // make sure a!=0
+    a += 1; // make sure a!=0
     v = v / a;
 
     a = a + v;
     a = a - v;
     a = a * v;
-    v += (ft)1; // make sure v!=0
+    v += 1; // make sure v!=0
     a = a / v;
 
     v = a + v;
     v = a - v;
     v = a * v;
-    v += (ft)1; // make sure v!=0
+    v += 1; // make sure v!=0
     v = a / v;
 
     v -= v;
@@ -152,7 +159,7 @@ struct ScalarOperatorTest
     v += v;
     v += a;
     v *= a;
-    a += (ft)1; // make sure a!=0
+    a += 1; // make sure a!=0
     v /= a;
 
     b = (v == a);
@@ -204,15 +211,27 @@ struct ScalarOrderingTest
   }
 };
 
+template<typename T>
+struct Epsilon
+{
+  static T value() { return T(1e-6); }
+};
+
+template<>
+struct Epsilon<int>
+{
+  static int value() { return 0; }
+};
+
 // scalar ordering doesn't work for complex numbers
 template <class rt, int d>
 struct DotProductTest
 {
   DotProductTest() {
     typedef std::complex<rt> ct;
-    const rt myEps(1e-6);
+    DUNE_UNUSED const rt myEps = Epsilon<rt>::value();
 
-    dune_static_assert(
+    static_assert(
       ( Dune::is_same< typename Dune::FieldTraits<rt>::real_type, rt>::value ),
       "DotProductTest requires real data type as template parameter!"
       );
@@ -225,8 +244,8 @@ struct DotProductTest
 
     const bool isRealOne = Dune::is_same<typename Dune::FieldTraits<rt>::field_type,typename Dune::FieldTraits<rt>::real_type>::value;
     const bool isRealIVec = Dune::is_same<typename Dune::FieldTraits<ct>::field_type,typename Dune::FieldTraits<ct>::real_type> ::value;
-    dune_static_assert(isRealOne,"1-vector expected to be real");
-    dune_static_assert(!isRealIVec,"i-vector expected to be complex");
+    static_assert(isRealOne,"1-vector expected to be real");
+    static_assert(!isRealIVec,"i-vector expected to be complex");
 
     ct result = ct();
     ct length = ct(d);
@@ -305,6 +324,8 @@ public:
     ScalarOperatorTest< complex<ft> >();
     // ordering doesn't work for complex numbers
 
+    // --- test with an integer
+    ScalarOperatorTest< ft, int >();
     // --- test next lower dimension
     FieldVectorMainTest<ft,ft,0>();
   }
@@ -343,15 +364,38 @@ test_infinity_norms()
   assert(std::abs(v.infinity_norm_real()-14.0) < 1e-10); // max(7,14)
 }
 
+void
+test_initialisation()
+{
+  DUNE_UNUSED Dune::FieldVector<int, 2> const b = { 1, 2 };
+
+  assert(b[0] == 1);
+  assert(b[1] == 2);
+}
+
 int main()
 {
   try {
     FieldVectorTest<int, 3>();
     FieldVectorTest<float, 3>();
     FieldVectorTest<double, 3>();
+    FieldVectorTest<int, 1>();
+    FieldVectorTest<double, 1>();
+#if HAVE_GMP
+    // we skip the complex test and the int test, as these will be very hard to implement with GMPField
+    typedef Dune::GMPField<128u> ft;
+    FieldVectorMainTest<ft,ft,3>();
+    FieldVectorMainTest<ft,ft,2>();
+    FieldVectorMainTest<ft,ft,1>();
+    FieldVectorMainTest<ft,ft,0>();
+    ScalarOperatorTest<ft>();
+    ScalarOrderingTest<ft>();
+    DotProductTest<ft,3>();
+#endif // HAVE_GMP
 
     test_nan();
     test_infinity_norms();
+    test_initialisation();
   } catch (Dune::Exception& e) {
     std::cerr << e << std::endl;
     return 1;
